<?php
    
    use artbox\core\helpers\ImageHelper;
    use common\models\blog\Article;
    use common\models\blog\Tag;
    use artbox\core\helpers\Url;
    use frontend\widgets\MicroDataWidget;
    use yii\web\View;
    
    /**
     * @var View    $this
     * @var Article $model
     * @var Tag[]   $tags
     * @var \artbox\core\forms\Module $module
     * @var \artbox\core\forms\Module $moduleAnswer
     */
    
    $this->params[ 'breadcrumbs' ][] = [
        'label' => \Yii::t('app', 'Блог'),
        'url'   => [ 'blog/index' ],
    ];
    
    $this->params[ 'breadcrumbs' ][] = $model->language->title;
    
    $module = \Yii::$app->getModule('comments');
    $module->inputOptions += ['entity_id' => [
        'type'    => 'hiddenInput',
        'options' => ['value' => $model->id],
    ]];
    $module->inputOptions += ['entity' => [
        'type'    => 'hiddenInput',
        'options' => ['value' => \common\models\Book::class],
    ]];
    $module->inputOptions += ['parent_id' => [
        'type'    => 'hiddenInput',
        'options' => ['value' => ''],
    ]];
    
    $moduleAnswer = \Yii::$app->getModule('commentsChild');
    $moduleAnswer->inputOptions += ['book_id' => [
        'type'    => 'hiddenInput',
        'options' => ['value' => $model->id],
    ]];
    $moduleAnswer->inputOptions += ['parent_id' => [
        'type'    => 'hiddenInput',
        'options' => ['value' => ''],
    ]];
    
    $this->params['blog'] = true;
?>



<section class="blog-view-section">
  <div class="container">
    <div class="row">
      <div class="col-xs-12">
        <h1 class="title-blog-view">
          <?=$model->language->title?>
        </h1>
      </div>
      <div class="col-xs-12">
        <div class="style icons-blog-wr">
          <span><?=date('d.m.Y', $model->created_at)?></span>
          <span><?=$model->view?> переглядів</span>
          <span><?=count($model->activeComments)?> коментарів</span>
        </div>
      </div>
      <div class="col-xs-12 col-sm-12 blog-view">
        <!--556x320-->
          <?=ImageHelper::set(!empty($model->image) ? $model->image->getPath() : null)->cropResize(556, 320)->renderImage(['style' => 'float:left'])?>
          <?=$model->language->body?>
      </div>
      <div class="col-xs-12 col-sm-12">
        <?php if (!empty($model->tags)){?>
        <div class="style items-blog-tags">
            <?php foreach ($model->tags as $tag){?>
              <a href="<?=Url::to(['alias' => $tag->language->alias])?>"><?=$tag->language->label?></a>
            <?php } ?>
        </div>
        <?php } ?>
      </div>
    </div>
    <div class="row">
      <div class="col-xs-12 col-sm-12">
        <div class="card-desk-title">коментарі</div>
      </div>
    </div>
    <div class="row">
      <div class="col-xs-12 col-sm-6 col-md-6 comments-card-col">
          <?php if (!empty($model->activeComments)){?>
            <div class="hidden-comments-form-card style" style="display: none;">
              <div class="style card-form-add-wrapp">
                  <?php $moduleAnswer->renderForm($this)?>
              </div>
            </div>
            <div class="style">
                <?php foreach ($model->activeComments as $comment){?>
                  <div class="comments-card-wr style">
                    <div class="style comments-card-autor"><?=$comment->name?></div>
                    <div class="style comments-card-text"><?=$comment->comment?></div>
                    <div class="style answers-wr">
                      <span data-id="<?=$comment->id?>">відповісти</span>
                    </div>
                      <?php foreach ($comment->activeComments as $child){?>
                        <div class="comments-card-ansvers-text-wr style">
                          <div class="style comments-card-autor-ansvers comments-card-autor"><?=$child->name?></div>
                          <div class="comments-card-text style">
                              <?=$child->comment?>
                          </div>
                        </div>
                      <?php } ?>
                  </div>
                <?php } ?>
            </div>
          <?php } ?>
      </div>
      <div class="col-xs-12 hidden-sm col-md-1"></div>
      <div class="col-xs-12 col-sm-6 col-md-5">
        <div class="style card-form-add-wrapp">
          <?php $module->renderForm($this)?>
        </div>
      </div>
      <div class="col-xs-12 border-blog-comments"></div>
    </div>
    <?php if (!empty($model->relatedBlogArticles)){?>
    <div class="row">
      <div class="col-xs-12">
        <div class="read-more-blog-view">читайте також</div>
      </div>
    </div>
    <div class="row">
      <?php foreach ($model->relatedBlogArticles as $article){?>
      <div class="col-xs-12 col-sm-4 items-blog-view-wr">
        <div class="items-blog-view">
          <div class="style icons-blog-wr">
            <span><?=date('d.m.Y', $article->created_at)?></span>
            <span><?=$article->view?></span>
            <span>48</span>
          </div>
          <a class="title-items-blog-view" href="<?=Url::to(['alias' => $article->language->alias])?>">
              <?=ImageHelper::set((!empty($article->image)) ? $article->image->getUrl() : null)->cropResize(360, 207)->renderImage()?>
  
            <p><?=$article->language->title?></p>
          </a>
          <?php if (!empty($article->tags)){?>
          <div class="style items-blog-tags">
              <?php foreach ($article->tags as $tag){?>
                <a href="<?=Url::to(['alias' => $tag->language->alias])?>"><?=$tag->language->label?></a>
              <?php } ?>
          </div>
          <?php } ?>
        </div>
      </div>
      <?php } ?>
    </div>
    <?php } ?>
  </div>
</section>
<!-- /#content -->
<?=MicroDataWidget::widget(['model' => $model, 'type' => 'NewsArticle'])?>
  