<?php
    
    /**
     * @var View           $this
     * @var string         $content
     * @var SeoComponent   $seo
     * @var User           $user
     * @var PageCategory[] $pageCategories
     * @var \artbox\core\forms\Module $module;
     */
    
    use artbox\core\components\SeoComponent;
    use artbox\core\helpers\ImageHelper;
    use artbox\core\models\Feedback;
    use artbox\core\models\PageCategory;
    use artbox\core\models\User;
    use artbox\core\seo\widgets\SeoBreadcrumbs;
    use common\models\Settings;
    use frontend\assets\AppAsset;
    use frontend\widgets\MicroDataWidget;
    use yii\bootstrap\Html;
    use artbox\core\helpers\Url;
    use yii\web\View;
    
    
    AppAsset::register($this);
    $user = \Yii::$app->user->identity;
    $seo = Yii::$app->get('seo');
    $feedback = new Feedback();
    $settings = Settings::getInstance();
    $controller = Yii::$app->controller;
    $default_controller = Yii::$app->defaultRoute;
    $isHome = ( ( $controller->id === $default_controller ) && ( $controller->action->id === $controller->defaultAction ) ) ? true : false;
    

    
    $this->registerMetaTag(
        [
            'name'    => 'description',
	        'content' => (!$isHome) ? $seo->desc :
		        'Щоб зберегти історію, передати своїм дітям спогади про війну,
                 про справжню війну, яка триває зараз... 
                 Ми створили проект “Моя війна. Бібліотека під редакцією Юрія Бутусова”.',
        ]
    );
    $module = \Yii::$app->getModule('feedback');
    
    if (\Yii::$app->session->hasFlash('success')) {
        $message = \Yii::$app->session->getFlash('success');
        $js = <<<JS
      success("$message");
JS;
        $this->registerJs($js, View::POS_READY);
    }
    
    $this->registerMetaTag(
        [
            'name'    => 'robots',
	    'content' => 'noindex, nofollow',
           // 'content' => $seo->robots,
        ]
    );
?>

<?php $this->beginPage() ?>
  <!DOCTYPE html>
  <html xmlns="http://www.w3.org/1999/html" xmlns="http://www.w3.org/1999/html" lang="<?= \Yii::$app->language ?>">
    <head>
      <meta charset="<?= \Yii::$app->charset ?>">
      <meta name="viewport" content="width=device-width">
        <?= Html::csrfMetaTags() ?>
        <title><?= Html::encode((!$isHome) ? $seo->title : 'Проект "МОЯ ВІЙНА" - Бібліотека під редакцією Юрія Бутусова') ?></title>
        <?php $this->head() ?>
    </head>
    <body<?=isset($this->params['isBlog']) ? ' class="blog-page"' : ''?>>
        <?php $this->beginBody() ?>
      <header id="header_" class="section-box-header <?=!$isHome ? 'header-border' : ''?>">
        <div class="container">
          <div class="row">
            <div class="col-xs-12 col-sm-12 col-md-2 col-lg-3 logo-wrapp">
              <a href="<?php echo \frontend\helpers\Url::home(); ?>" class="logo">
                  <?php
                      if ($settings->logo != null){
                          echo '<img src="/storage/logo/'.$settings->logo.'" alt="">';
                      }else{
                          echo ImageHelper::set(null)
                                          ->setHeight(37)
                                          ->renderImage(
                                              [
                                                  'alt' => $settings->name,
                                              ]
                                          );
                      }
    
                  ?></a>
              <div class="menu_mob hidden visible-xs visible-sm">
                <div></div>
                <div></div>
              </div>
            </div>
            <div class="col-xs-12 hidden-xs hidden-sm col-sm-3 col-md-3 header-menu">
              <ul>
                <li><a href="<?=Url::to(['site/about'])?>">Про проект</a></li>
                <li><a href="<?=Url::to(['book/index'])?>">Книги</a></li>
              </ul>
            </div>
            
            <div class="col-xs-12 hidden-xs hidden-sm col-sm-4 col-md-5 col-lg-4 btns_header">
              <a href="<?=\Yii::$app->user->isGuest ? Url::to(['site/register']) : Url::to(['book/add'])?>" class="btn_ add-book"><span>Додати книгу</span></a>
              <a href="<?=Url::to(['support/search'])?>" class="btn_ to-support">Підтримати</a>
            </div>
            <?php if (\Yii::$app->user->isGuest){?>
            <div class="col-xs-12 hidden-xs hidden-sm col-sm-2 col-md-2">
              <a href="<?=Url::to(['site/login'])?>" class="login">
                Вхiд
              </a>
            </div>
            <?php } else { ?>
              <div class="col-xs-12 hidden-xs hidden-sm col-sm-2 col-md-2">
                <a class="auth" href="<?=Url::to(['author/index'])?>">
                  Особистий кабінет
                </a>
              </div>
            <?php }?>
          
          </div>
        </div>
      
      </header>
      
      <!-- #content должен быть в main.php -->
      <div id="content_" class="section-box-content">
        
        <!-- start breadcrumbs -->
        <?php if (isset($this->params['breadcrumbs'])){?>
        <section class="section-breadcrumb">
          <div class="container">
            <div class="row">
              <div class="col-xs-12 col-sm-12 breadcrumb-wrapp">
                  <?=SeoBreadcrumbs::widget([
                                                'links' => isset($this->params[ 'breadcrumbs' ]) ? $this->params[ 'breadcrumbs' ] : [],
                                            ])?>
              </div>
            </div>
          </div>
        </section>
    <?php } ?>
        <!-- end breadcrumbs -->
        
        <!-- start content -->
        <?=$content?>
        
        <!-- end content -->
      
      </div>
      <?php
      if (!isset($this->params['blog'])){
        echo MicroDataWidget::widget(['type' => 'Organization']);
      }
      ?>
      <footer id="footer_" class="section-box-footer" >
        <div class="container">
          <div class="row" style="position: relative">
            <nav class="col-xs-12 col-sm-9 col-md-9">
              <ul class="footer-menu">
                <li><a href="<?=Url::to(['site/about'])?>">Про проект</a></li>
<!--                <li><a href="#">Партнери</a></li>-->
<!--                <li><a href="#">Контакти</a></li>-->
                <li><a href="<?=Url::to(['blog/index'])?>">Блог</a></li>
              </ul>
            </nav>
            <div class="footer-btn">
              <a href="<?=Url::to(['support/search'])?>" class="btn_">Підтримати</a>
            </div>
          </div>
        </div>
      </footer>
      
      <div class="mobile-menu-hidden">
        <div class="close-lang-mob">
          Меню
          <div class="close-mobile-menu"></div>
        </div>
        <div class="style mob-list">
          <ul>
            <li><a href="<?=Url::to(['site/about'])?>">Про проект</a></li>
            <li><a href="<?=Url::to(['book/index'])?>">Книги</a></li>
<!--            <li><a href="#">Партнери</a></li>-->
<!--            <li><a href="--><?//=Url::to(['site/contacts'])?><!--">Контакти</a></li>-->
            <li><a href="<?=Url::to(['blog/index'])?>">Блог</a></li>
            <li><a href="<?=Url::to(['site/login'])?>">Вхiд</a></li>
          </ul>
        </div>
        <div class="style btns-menu-mob">
          <div class="style"><a href="<?=\Yii::$app->user->isGuest ? Url::to(['site/register']) : Url::to(['book/add'])?>" class="btn_ add-book"><span>Додати книгу</span></a></div>
          <div class="style"><a href="<?=Url::to(['support/search'])?>" class="btn_ to-support">Підтримати</a></div>
        </div>
      </div>
      
      <div class="call-mobile-wr" style="display: none;">
        <!--<div class="button-call-mob">-->
        <!--<div class="callback-footer modal-link" data-form="callback"><span></span>Обратный звонок</div>-->
        <!--</div>-->
        <div class="call-mobile">
          <div class="call-mobile-td">
<?php if (!empty($settings->phone) or !empty($settings->phone2)){
    $phones = array_merge(explode(';', $settings->phone2) , [$settings->phone]);
    ?>
    <?php foreach ($phones as $phone){?>
            <div class="button-call-mob">
              <a class="button-call_" href="tel:<?=$phone?>">
                <p>Позвонить</p>
                <div><span></span></div>
                <span><?=$phone?></span>
              </a>
            </div>
        <?php }?>
            
            <div class="button-call-mob"><a class="call-sms" href="sms:<?=$settings->phone?>">Отправить SMS</a>
            </div>
    <?php } ?>
<!--            <div class="button-call-mob">-->
<!--              <a class="call-contact" href="contacts/joule.vcf">Добавить в контакты</a>-->
<!--            </div>-->
          </div>
        </div>
      </div>
      
      <div id="overlay" style="display: none;"></div>
      <div id="overlay-catalog" style="display: none;"></div>
      <div id="callback" class="forms_" style="display: none;">
        <span id="modal_close"></span>
        <div class="style form-title">Обратный звонок</div>
        <form action="">
          <div class="input-wr">
            <label for="inp-11">Имя</label>
            <input id="inp-11" type="text">
          </div>
          <div class="input-wr phones_mask">
            <label for="inp-22">Телефон</label>
            <input id="inp-22" type="text">
          </div>
          <div class="input-wr">
            <label for="inp-33">Сообщение</label>
            <textarea id="inp-33" name="" cols="30" rows="10"></textarea>
          </div>
          <div class="button-wr">
            <button type="submit">отправить</button>
          </div>
        </form>
      </div>
      <div id="success_form" style="display: none;">
        <span id="modal_close"></span>
        <div class="txt-success"><span>Спасибо за Ваш запрос!</span><p>Мы свяжемся с вами в ближайшее время.</p></div>
      </div>
      <?php $this->endBody()?>
    </body>
  </html>
<?php $this->endPage() ?>
